@@ -99,6 +99,24 @@ gboolean stickynote_delete_cb(GtkWidget *widget, GdkEvent *event, StickyNote *no
 	return TRUE;
 }
 
+/* Sticky Window Callback : Popup the right click menu. */
+gboolean
+stickynote_show_popup_menu (GtkWidget *widget, GdkEventButton *event, GtkWidget *popup_menu)
+{
+  
+
+	if (event->type == GDK_BUTTON_PRESS && event->button == 3)
+	{
+		gtk_menu_popup (GTK_MENU (popup_menu),
+				NULL, NULL,
+				NULL, NULL,
+				event->button, event->time);
+	}
+
+	return FALSE;
+}
+
+
 /* Popup Menu Callback : Create a new sticky note */
 void popup_create_cb(GtkWidget *widget, StickyNote *note)
 {
@@ -112,9 +130,9 @@ void popup_destroy_cb(GtkWidget *widget, StickyNote *note)
 }
 
 /* Popup Menu Callback : Lock/Unlock selected sticky note */
-void popup_toggle_lock_cb(GtkWidget *widget, StickyNote *note)
+void popup_toggle_lock_cb(GtkToggleAction *action, StickyNote *note)
 {
-	stickynote_set_locked(note, gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget)));
+	stickynote_set_locked(note, gtk_toggle_action_get_active(action));
 }
 
 /* Popup Menu Callback : Change sticky note properties */
@@ -150,9 +168,9 @@ void properties_apply_color_cb(StickyNote *note)
 				color.green / 256,
 				color.blue / 256);
 		font_color_str = g_strdup_printf ("#%.2x%.2x%.2x",
-				color.red / 256,
-				color.green / 256,
-				color.blue / 256);
+				font_color.red / 256,
+				font_color.green / 256,
+				font_color.blue / 256);
 	}
 	
 	stickynote_set_color (note, color_str, font_color_str, TRUE);
